/* vi:set ts=8 sts=0 sw=8:
 * $Id: misc.c,v 1.7 2000/05/20 02:37:56 kahn Exp kahn $
 *
 * Copyright (C) 2000 Andy C. Kahn
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <gnome.h>
#include <string.h>
#include "misc.h"

/*** global function definitions ***/
void
my_gtk_events_flush(void)
{
	while (gtk_events_pending())
		gtk_main_iteration();
} /* my_gtk_events_flush */


/*
 * Gets the widget corresponding to the specified xml.
 */
GtkWidget *
my_glade_widget_get(GladeXML *xml, char *name, int flags)
{
	GtkWidget *wgt;

	if ((wgt = glade_xml_get_widget(xml, name)) == NULL) {
		g_warning("Widget missing: %s\n", name);
		return NULL;
	}

	if (flags & GLADE_MODAL)
		gtk_window_set_modal(GTK_WINDOW(wgt), TRUE);
	if (flags & GLADE_POS_MOUSE)
		gtk_window_set_position(GTK_WINDOW(wgt), GTK_WIN_POS_MOUSE);
	if (flags & GLADE_SHOW)
		gtk_widget_show(wgt);
	if (flags & GLADE_HIDE)
		gtk_widget_hide(wgt);

	return wgt;
} /* my_glade_widget_get */


/*
 * Loads the Glade XML object from the .glade file.
 */
GladeXML *
my_glade_xml_get(char *root)
{
	GladeXML *xml;
	char *glade_file;

	if (g_file_exists("./gnome-find.glade"))
		return glade_xml_new("./gnome-find.glade", root);

	glade_file = g_concat_dir_and_file(DATADIR, "gnome-find.glade");
	xml = glade_xml_new(glade_file, root);
	g_free(glade_file);
	return xml;
} /* my_glade_xml_get */


/* the end */
