/* vi:set ts=8 sts=0 sw=8:
 * $Id: results.c,v 1.5 2000/05/20 18:11:11 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include "win.h"
#include "main.h"
#include "misc.h"
#include "file.h"
#include "msgbar.h"


enum ef_results_id_e {
	Ef_results_dialog,
	Ef_results_clist,	/* clist */
	Ef_results_errors,	/* clist */
	Ef_results_cont_errors,	/* scrolled window */
	Ef_results_num_found,	/* label */
	Ef_results_toolbar,	/* toolbar */
	Ef_results_ok,		/* button */
	Ef_results_err,		/* button */
	Ef_results_open,	/* button */
	Ef_results_delete,	/* button */
	Ef_results_copy,	/* button */
	Ef_results_print,	/* button */
	Ef_results_execute,	/* button */
	Ef_results_add,		/* button */
	Ef_results_remove,	/* button */
	Ef_results_info,	/* button */
	Ef_results_MAX
};
typedef enum ef_results_id_e ef_results_id_t;


static void results_ok_cb(GtkWidget *wgt, gpointer cbdata);
static void results_err_cb(GtkWidget *wgt, gpointer cbdata);


static ef_t ef_results_widgets[] = {
	{
		"Search Results",
		Ef_results_dialog,
		Ef_wgt_dialog,
	},
	{
		"clist_results",
		Ef_results_clist,
		Ef_wgt_clist,
	},
	{
		"clist_errors",
		Ef_results_errors,
		Ef_wgt_clist,
	},
	{
		"scrwin_errors",
		Ef_results_cont_errors,
		Ef_wgt_dont_care,
	},
	{
		"label_num_found",
		Ef_results_num_found,
		Ef_wgt_label,
	},
	{
		"tb_results",
		Ef_results_toolbar,
		Ef_wgt_toolbar,
	},
	{
		"but_results_ok",
		Ef_results_ok,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(results_ok_cb)
	},
	{
		"but_results_err",
		Ef_results_err,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(results_err_cb)
	},
	{
		"but_file_open",
		Ef_results_open,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_open_cb)
	},
	{
		"but_file_delete",
		Ef_results_delete,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_delete_cb)
	},
	{
		"but_file_copy",
		Ef_results_copy,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_copy_cb)
	},
	{
		"but_file_print",
		Ef_results_print,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_print_cb)
	},
	{
		"but_file_execute",
		Ef_results_execute,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_execute_cb)
	},
	{
		"but_file_add",
		Ef_results_add,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_add_cb)
	},
	{
		"but_file_remove",
		Ef_results_remove,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_remove_cb)
	},
	{
		"but_file_info",
		Ef_results_info,
		Ef_wgt_button,
		GTK_SIGNAL_FUNC(file_info_cb)
	},
	{ NULL }
}; /* ef_results_widgets[] */


static void
results_ok_cb(GtkWidget *wgt, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;

	gtk_widget_hide(w->reswgts[Ef_results_dialog]);
} /* results_ok_cb */


static void
results_err_cb(GtkWidget *wgt, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;

	gtk_widget_show(w->reswgts[Ef_results_cont_errors]);
} /* results_err_cb */


void
results_widgets_setup(win_t *w)
{
	GladeXML *xml;
	ef_t *efp;
	int num = 0;

	g_assert(w);

	if (w->reswgts) {
		gtk_widget_destroy(w->reswgts[Ef_results_dialog]);
	} else {
		num = (sizeof(ef_results_widgets) /
		       sizeof(ef_results_widgets[0])) - 1;
		w->reswgts = g_new0(GtkWidget *, num);
	}

	xml = my_glade_xml_get("Search Results");
	g_assert(xml);
#ifdef ENABLE_DEBUG
	g_print("results_widgets_setup: num = %d (max = %d)\n",
		num, Ef_results_MAX);
	num = 0;
#endif
	for (efp = ef_results_widgets; efp->glname; efp++) {
		win_widgets_setup(xml, w, w->reswgts, efp);
#ifdef ENABLE_DEBUG
		g_assert(efp->wgt_id == num);
		num++;
#endif
	}
	gtk_object_destroy(GTK_OBJECT(xml));
	gtk_window_set_position(GTK_WINDOW(w->reswgts[Ef_results_dialog]),
				GTK_WIN_POS_MOUSE);
	gtk_window_set_transient_for(GTK_WINDOW(w->reswgts[Ef_results_dialog]),
				     GTK_WINDOW(win_main_toplev(w)));
} /* results_widgets_setup */


void
results_found_set(win_t *w)
{
	char *buf;

	buf = g_strdup_printf(_("Files found: %d"), w->num_found);
	gtk_label_set_text(GTK_LABEL(w->reswgts[Ef_results_num_found]), buf);
	g_free(buf);
} /* results_found_set */


void
results_dialog_show(win_t *w)
{
	gtk_widget_set_sensitive(w->reswgts[Ef_results_err], w->num_errs);
	gtk_widget_show(w->reswgts[Ef_results_dialog]);
} /* results_dialog_show */


void
results_prev_show(win_t *w)
{
	if (w->reswgts && w->reswgts[Ef_results_dialog] &&
	    GTK_IS_WIDGET(w->reswgts[Ef_results_dialog]))
		gtk_widget_show(w->reswgts[Ef_results_dialog]);
	else
		msgbar_printf(w, _("No previous search results."));
} /* results_prev_show */


void
results_dialog_destroy(win_t *w)
{
	if (w->reswgts && w->reswgts[Ef_results_dialog])
		gtk_widget_destroy(w->reswgts[Ef_results_dialog]);
} /* results_dialog_destroy */


void
results_add(win_t *w, char *text)
{
	char *buf[] = { text, NULL };

	g_assert(w->reswgts[Ef_results_clist]);
	(void)gtk_clist_append(GTK_CLIST(w->reswgts[Ef_results_clist]), buf);

	w->num_found++;
	if (w->num_found % 25 == 0)
		msgbar_printf(w, _("Total files found: %d"), w->num_found);
} /* results_add */


void
results_errors_add(win_t *w, char *text)
{
	char *buf[] = { text, NULL };

	g_assert(w->reswgts[Ef_results_errors]);
	(void)gtk_clist_append(GTK_CLIST(w->reswgts[Ef_results_errors]), buf);
	w->num_errs++;
} /* results_add */


/* the end */
